==> huaweicloudsdkdrs-3.1.133-py2.py3-none-any.whl: huaweicloudsdkdrs/v3/model/batch_limit_speed_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchLimitSpeedReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'speed_limits': 'list[LimitSpeedReq]'
    }

    attribute_map = {
        'speed_limits': 'speed_limits'
    }

    def __init__(self, speed_limits=None):
        """BatchLimitSpeedReq

        The model defined in huaweicloud sdk

        :param speed_limits: 灾备限速设置信息
        :type speed_limits: list[:class:`huaweicloudsdkdrs.v3.LimitSpeedReq`]
        """
        
        

        self._speed_limits = None
        self.discriminator = None

        self.speed_limits = speed_limits

    @property
    def speed_limits(self):
        """Gets the speed_limits of this BatchLimitSpeedReq.

        灾备限速设置信息

        :return: The speed_limits of this BatchLimitSpeedReq.
        :rtype: list[:class:`huaweicloudsdkdrs.v3.LimitSpeedReq`]
        """
        return self._speed_limits

    @speed_limits.setter
    def speed_limits(self, speed_limits):
        """Sets the speed_limits of this BatchLimitSpeedReq.

        灾备限速设置信息

        :param speed_limits: The speed_limits of this BatchLimitSpeedReq.
        :type speed_limits: list[:class:`huaweicloudsdkdrs.v3.LimitSpeedReq`]
        """
        self._speed_limits = speed_limits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchLimitSpeedReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdrs-3.1.146-py2.py3-none-any.whl: huaweicloudsdkdrs/v3/model/batch_limit_speed_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchLimitSpeedReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'speed_limits': 'list[LimitSpeedReq]'
    }

    attribute_map = {
        'speed_limits': 'speed_limits'
    }

    def __init__(self, speed_limits=None):
        r"""BatchLimitSpeedReq

        The model defined in huaweicloud sdk

        :param speed_limits: 灾备限速设置信息
        :type speed_limits: list[:class:`huaweicloudsdkdrs.v3.LimitSpeedReq`]
        """
        
        

        self._speed_limits = None
        self.discriminator = None

        self.speed_limits = speed_limits

    @property
    def speed_limits(self):
        r"""Gets the speed_limits of this BatchLimitSpeedReq.

        灾备限速设置信息

        :return: The speed_limits of this BatchLimitSpeedReq.
        :rtype: list[:class:`huaweicloudsdkdrs.v3.LimitSpeedReq`]
        """
        return self._speed_limits

    @speed_limits.setter
    def speed_limits(self, speed_limits):
        r"""Sets the speed_limits of this BatchLimitSpeedReq.

        灾备限速设置信息

        :param speed_limits: The speed_limits of this BatchLimitSpeedReq.
        :type speed_limits: list[:class:`huaweicloudsdkdrs.v3.LimitSpeedReq`]
        """
        self._speed_limits = speed_limits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchLimitSpeedReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
